<?php

/**
 * @file
 *  Rules integration for the Syndeploy module.
 */

/**
 * Implementation of hook_rules_action_info().
 * @ingroup rules
 */
function syndeploy_rules_action_info() {
  return array(
    'syndeploy_action_log_entry_create' => array(
      'label' => t('Create a log entry to record a site change'),
      'arguments' => array(
        'node' => array('type' => 'node', 'label' => t('Changed item')),
        'updater' => array('type' => 'user', 'label' => t('Updater')),
        'type' => array('type' => 'number', 'label' => t('Change type ID')),
      ),
      'module' => 'Syndeploy',
    ),
  );
}

/**
 * Creates a log entry to record a site change.
 *
 * @param $changed
 *   The current item that's being updated.
 * @param $updater
 *   The current user doing the updating.
 * @param $type
 *   The code for this update type.
 */
function syndeploy_action_log_entry_create($changed, $updater, $type) {

  // Set the content type of the log entry.
  static $log_entry_type = 'syndeploy_log_entry';

  // If we're dealing with a log entry itself, don't do anything.
  if ($changed->type == $log_entry_type) {
    return;
  }

  // Create a new node to serve as an update record.
  $update_record = new StdClass;

  // Set the proper type so that some attributes can be set autormatically.
  $update_record->type = $log_entry_type;
  node_object_prepare($update_record);

  /*
   * Don't set the title.  We don't need it for Views, and it would take up
   * precious DB space.
   */

  // Validate & submit the new node.
  node_validate($update_record);
  $update_record = node_submit($update_record);

  /*
   * Set the author to the administrator.  We don't want the updater to own
   * these nodes because he or she can delete them.  Instead, we have a
   * separate field containing the user ID of the updater.  This gets added
   * below.
   */
  $update_record->uid = 1;

  // Fill in the CCK data.
  $update_record->field_syndeploy_entity_uuid[0]['value'] = $changed->uuid;
  $update_record->field_syndeploy_entity_rev_uuid[0]['value'] = $changed->revision_uuid;
  $update_record->field_syndeploy_update_type[0]['value'] = $type;
  $update_record->field_syndeploy_user_id[0]['uid'] = $updater->uid;

  // Save it.
  node_save($update_record);
}

